@@ -17,7 +17,16 @@ class ExecutionType(Enum):
 
     @staticmethod
     def by_priority() -> List[ExecutionType]:
-        return [ExecutionType.SELL, ExecutionType.EOD, ExecutionType.BUY]
+        return [ExecutionType.EOD, ExecutionType.SELL, ExecutionType.BUY]
 
     def value(self) -> str:
         return self.name.lower()
+
+    @staticmethod
+    def to_method_name(execution_type: ExecutionType) -> str:
+        return {
+            ExecutionType.EOD: "sell",
+            ExecutionType.SELL: "sell",
+            ExecutionType.BUY: "buy",
+            ExecutionType.WAIT: "noop",
+        }[execution_type]
